==> haskell-src-1.0.4-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-src
version:              1.0.4
visibility:           public
id:                   haskell-src-1.0.4-AvD9RNVt10bC4XdPzYlUWv
key:                  haskell-src-1.0.4-AvD9RNVt10bC4XdPzYlUWv
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Simon Marlow, Sven Panne and Noel Winstanley
stability:            stable
synopsis:             Support for manipulating Haskell source code
description:
    The @haskell-src@ package provides support for manipulating Haskell
    source code. The package provides a lexer, parser and
    pretty-printer, and a definition of a Haskell abstract syntax tree
    (AST). Common uses of this package are to parse or generate
    <http://www.haskell.org/onlinereport/ Haskell 98> code.

category:             Language
abi:                  e44aa253b2135bc8bd7856fc38786984
exposed:              True
exposed-modules:
    Language.Haskell.Lexer Language.Haskell.ParseMonad
    Language.Haskell.ParseUtils Language.Haskell.Parser
    Language.Haskell.Pretty Language.Haskell.Syntax

import-dirs:          /usr/lib/ghc-9.2.8/site-local/haskell-src-1.0.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/haskell-src-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src
hs-libraries:         HShaskell-src-1.0.4-AvD9RNVt10bC4XdPzYlUWv
depends:
    array-0.5.4.0 base-4.16.4.0 pretty-1.1.3.6
    syb-0.7.2.4-96PLGA9ePRoKEvwVQEltSr

haddock-interfaces:   /usr/share/doc/haskell-src/html/haskell-src.haddock
haddock-html:         /usr/share/doc/haskell-src/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-1.0.4-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-src
version:              1.0.4
visibility:           public
id:                   haskell-src-1.0.4-KLxZrRUOGfLEOosFRFUZMG
key:                  haskell-src-1.0.4-KLxZrRUOGfLEOosFRFUZMG
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Simon Marlow, Sven Panne and Noel Winstanley
stability:            stable
synopsis:             Support for manipulating Haskell source code
description:
    The @haskell-src@ package provides support for manipulating Haskell
    source code. The package provides a lexer, parser and
    pretty-printer, and a definition of a Haskell abstract syntax tree
    (AST). Common uses of this package are to parse or generate
    <http://www.haskell.org/onlinereport/ Haskell 98> code.

category:             Language
abi:                  05b1e1ab90cc884d4550eff1cafded2c
exposed:              True
exposed-modules:
    Language.Haskell.Lexer Language.Haskell.ParseMonad
    Language.Haskell.ParseUtils Language.Haskell.Parser
    Language.Haskell.Pretty Language.Haskell.Syntax

import-dirs:          /usr/lib/ghc-9.2.8/site-local/haskell-src-1.0.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/haskell-src-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src
hs-libraries:         HShaskell-src-1.0.4-KLxZrRUOGfLEOosFRFUZMG
depends:
    array-0.5.4.0 base-4.16.4.0 pretty-1.1.3.6
    syb-0.7.2.4-89doc1zYrrWCF1u4CgIEo3

haddock-interfaces:   /usr/share/doc/haskell-src/html/haskell-src.haddock
haddock-html:         /usr/share/doc/haskell-src/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
